@@ -13,7 +13,8 @@ class BaseParser(object):
         self.layout_kwargs = layout_kwargs
         self.layout, self.dimensions = get_page_layout(
             filename, **layout_kwargs)
-        self.horizontal_text = get_text_objects(self.layout, ltype="lh")
-        self.vertical_text = get_text_objects(self.layout, ltype="lv")
+        self.images = get_text_objects(self.layout, ltype='image')
+        self.horizontal_text = get_text_objects(self.layout, ltype='horizontal_text')
+        self.vertical_text = get_text_objects(self.layout, ltype='vertical_text')
         self.pdf_width, self.pdf_height = self.dimensions
         self.rootname, __ = os.path.splitext(self.filename)
